@@ -24,7 +24,7 @@ class BrokerPublisher(ABC, MinosSetup):
         :param message: The message to be sent.
         :return: This method does not return anything.
         """
-        logger.info(f"Sending {message!r} message...")
+        logger.debug(f"Sending {message!r} message...")
         await self._send(message)
 
     @abstractmethod
